Userena Introduction — Userena v0.1.0 documentation

### Navigation

- index
- next |
- Userena v0.1.0 documentation »

# Userena Introduction

This documentation covers the first release of django-userena application. A Django application that takes care off all your account needs. These were selected by looking at web applications and picking those that every modern web application needs. A few examples of these are the following:

- After signup a user get’s a verification email. A user can make use of the application `USERENA_VERIFICATION_DAYS` days before having to verify their account. The user also get’s a notification if their account is still not verified `USERENA_VERIFICATION_NOTIFY_DAYS` days before the verification key get’s invalid.
- A user can signin with their e-mail address or username (as seen at Github). Django-userena will define which one is used and try to sign the user in with supplied credentials.
- At signin the user can choose to be remembered for `USERENA_REMEMBER_ME_DAYS` of time.
- Usernames defined in `USERENA_FORBIDDEN_USERNAMES` list are not allowed at signup.
- Changing your e-mail address also needs verification. Only after the URI inside the verification e-mail is clicked will the new e-mail address become active.
- Each account has their own detail page, for ex. `/accounts/jane/` and each account also has it’s own settings page accessible by the owner. For ex. `/accounts/me/`.

# Contents

- Installation.
  - Installing django-userena.
  - Required settings
- Settings
  - Userena settings
  - Django settings
- Commands.
  - Clean expired
  - Notify expired
- Todo
  - SSL
  - API

# Indices and tables

- Index
- Search Page

### Navigation

- index
- next |
- Userena v0.1.0 documentation »